Welcome to ClientVPS Mirrors

Help for package spongecake
Type: Package
Title: Transform a Movie into a Synthetic Picture
Version: 0.1.2
Author: Vincent Guyader
Maintainer: Vincent Guyader <vincent@thinkr.fr>
Description: Transform a Movie into a Synthetic Picture. A frame every 10 seconds is summarized into one colour, then every generated colors are stacked together.
License: GPL-3
Depends: R (≥ 3.0)
Encoding: UTF-8
LazyData: true
Imports: magrittr, ggplot2, jpeg, plyr
RoxygenNote: 6.0.1
SystemRequirements: FFmpeg (http://ffmpeg.org)
URL: https://github.com/ThinkRstat/spongecake
NeedsCompilation: no
Packaged: 2017-07-14 22:43:04 UTC; vincent
Repository: CRAN
Date/Publication: 2017-07-15 06:30:06 UTC

spongecake

Description

this package transform a movie into a simple image...

Examples

## Not run: 
#options(ffmpeg = "C:/ffmpeg-3.1.4-win64-static/bin/ffmpeg.exe") # windows user
library(magrittr)
gen_screenshot(movie = "D:/mymovie.avi") %>%
draw()%>%
print()

## End(Not run)

average_color

Description

return the average color from an image

Usage

average_color(img)

Arguments

img

the image (a array)


draw

Description

transform a folder of scrennshot into a synthetical picture

Usage

draw(folder)

Arguments

folder

the path of the folder

Examples

## Not run: 
#options(ffmpeg = "C:/ffmpeg-3.1.4-win64-static/bin/ffmpeg.exe") # windows user
library(magrittr)
gen_screenshot(movie = "D:/mymovie.avi") %>%
draw()

## End(Not run)

folder_average_color

Description

return the average color from all folder's images

Usage

folder_average_color(folder)

Arguments

folder

the path of the folder


gen_screenshot

Description

transform a movie into lot of screenshots

Usage

gen_screenshot(movie, folder = tempfile(), every = 10)

Arguments

movie

the path of the movie

folder

the path of the folder

every

timbe between each screenshot in seconds

Examples

## Not run: 
gen_screenshot(movie = "D:/mymovie.avi") %>%
browseURL()

## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.